@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 BEGIN {
-	our $VERSION = '0.25';
+	our $VERSION = '0.26';
 	
 	if ($] >= 5.016) {
 		require XSLoader;
@@ -38,7 +38,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
@@ -73,6 +73,13 @@ Version 0.25
 
 	1;
 
+
+=head1 DESCRIPTION
+
+The Const::XS module facilitates the creation of high-performance read-only variables in Perl. Beginning with Perl version 5.16, Const::XS is able to leverages XS, while older versions revert to a pure Perl fallback.If you would like to use the pure Perl version simply append ::PP to your use statement.
+
+	use Const::XS::PP qw/const/;
+
 =head1 EXPORTS
 
 =head2 const
@@ -137,49 +144,70 @@ The fifth function exported by this module is is_readonly. It will deeply check
 	use Const::XS;
 	use Readonly;
 
-	timethese(5000000, {
+
+	my $r = timethese(5000000, {
 		'Readonly' => sub {
-			Readonly my $string => "Hello World";
-			Readonly my %hash => (
-				a => 1,
-				b => 2,
-				c => 3
+			Readonly::Scalar my $string => "Hello World";
+			Readonly::Hash my %hash => (
+				a => $string,
+				b => $string,
+				c => $string
 			);
-			Readonly my @array => (
-				qw/1 2 3/
+			Readonly::Array my @array => (
+				qw/1 2 3/, $string, \%hash
 			);
+			$string;
+			$hash{a};
+			$array[0];
 		},
 		'Const::Fast' => sub {
 			Const::Fast::const my $string => "Hello World";
 			Const::Fast::const my %hash => (
-				a => 1,
-				b => 2,
-				c => 3
+				a => $string,
+				b => $string,
+				c => $string
 			);
 			Const::Fast::const my @array => (
-				qw/1 2 3/
+				qw/1 2 3/, $string, \%hash
 			);
+			$string;
+			$hash{a};
+			$array[0];
 		},
 		'XS' => sub {
 			Const::XS::const my $string => "Hello World";
 			Const::XS::const my %hash => (
-				a => 1,
-				b => 2,
-				c => 3
+				a => $string,
+				b => $string,
+				c => $string
 			);
 			Const::XS::const my @array => (
-				qw/1 2 3/
+				qw/1 2 3/, $string, \%hash
 			);
+			$string;
+			$hash{a};
+			$array[0];
 		}
 	});
 
+	cmpthese $r;
+
 ...
 
 	Benchmark: timing 5000000 iterations of Const::Fast, Readonly, XS...
-	Const::Fast: 18 wallclock secs (19.00 usr +  0.00 sys = 19.00 CPU) @ 263157.89/s (n=5000000)
-	  Readonly: 20 wallclock secs (19.77 usr +  0.01 sys = 19.78 CPU) @ 252780.59/s (n=5000000)
-		XS:  4 wallclock secs ( 3.31 usr +  0.03 sys =  3.34 CPU) @ 1497005.99/s (n=5000000)
+	Const::Fast: 21.4638 wallclock secs (21.45 usr +  0.00 sys = 21.45 CPU) @ 233100.23/s (n=5000000)
+	  Readonly: 33.0228 wallclock secs (33.00 usr +  0.00 sys = 33.00 CPU) @ 151515.15/s (n=5000000)
+		XS: 3.62688 wallclock secs ( 3.60 usr +  0.03 sys =  3.63 CPU) @ 1377410.47/s (n=5000000)
+			 Rate    Readonly Const::Fast          XS
+	Readonly     151515/s          --        -35%        -89%
+	Const::Fast  233100/s         54%          --        -83%
+	XS          1377410/s        809%        491%          --
 
+=head2 SEE ALSO
+
+L<Const::Fast>
+
+L<Readonly>
 
 =head1 AUTHOR
 
